@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import logging
-from typing import Iterable
 
 from dynamicprompts import constants
 from dynamicprompts.enums import SamplingMethod
@@ -16,10 +15,11 @@ logger = logging.getLogger(__name__)
 class CombinatorialPromptGenerator(PromptGenerator):
     def __init__(
         self,
-        wildcard_manager: WildcardManager,
+        wildcard_manager: WildcardManager | None = None,
         ignore_whitespace: bool = False,
         parser_config: ParserConfig = default_parser_config,
     ) -> None:
+        wildcard_manager = wildcard_manager or WildcardManager()
         self._context = SamplingContext(
             wildcard_manager=wildcard_manager,
             default_sampling_method=SamplingMethod.COMBINATORIAL,
@@ -31,5 +31,5 @@ class CombinatorialPromptGenerator(PromptGenerator):
         self,
         template: str | None,
         max_prompts: int | None = constants.MAX_IMAGES,
-    ) -> Iterable[str]:
-        return self._context.sample_prompts((template or ""), max_prompts)
+    ) -> list[str]:
+        return list(self._context.sample_prompts((template or ""), max_prompts))
