@@ -1,13 +1,13 @@
 from __future__ import annotations
-from typing import List
 
 from abc import ABC, abstractmethod
 
+
 class PromptGenerator(ABC):
     @abstractmethod
-    def generate(self, *args, **kwargs) -> List[str]:
+    def generate(self, *args, **kwargs) -> list[str]:
         pass
 
 
 class GeneratorException(Exception):
-    pass
\ No newline at end of file
+    pass
